Module combinators

Module combinators 

Dataflow combinators for Seq

Higher-order words that manage value flow on the stack, reducing the need for explicit stack shuffling (swap/rot/pick) or auxiliary stack usage (>aux / aux>).

These follow the concatenative tradition from Factor/Joy:

  • dip — hide top value, run quotation, restore value
  • keep — run quotation on top value, but preserve the original
  • bi — apply two quotations to the same value

Re-exports

pub use patch_seq_bi as bi;
pub use patch_seq_dip as dip;
pub use patch_seq_keep as keep;

Functions

patch_seq_bi
bi: Apply two quotations to the same value.
patch_seq_dip
dip: Hide top value, run quotation on the rest, restore value.
patch_seq_keep
keep: Run quotation on top value, but preserve the original.