patch_seq_dip

Function patch_seq_dip 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_dip(stack: Stack) -> Stack
dip: Hide top value, run quotation on the rest, restore value.

Stack effect: ( ..a x quot – ..b x ) where quot : ( ..a – ..b )

Equivalent to: swap >aux call aux>

Safety

  • Stack must have at least 2 values (quotation on top, preserved value below)
  • Top of stack must be a Quotation or Closure