patch_seq_dns_resolve

Function patch_seq_dns_resolve 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_dns_resolve(stack: Stack) -> Stack
Resolve a hostname to a list of IP-address strings.

Stack effect: ( String -- Variant Bool )

The Variant is a List (tag "List") of IP-string Value::Strings. On unresolvable hostname, empty result, or type mismatch, pushes (empty-list, false). Yields the strand cooperatively while the lookup runs on the worker pool.

Safety

Stack must have a String (hostname) on top.