patch_seq_map_fold

Function patch_seq_map_fold 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_map_fold(stack: Stack) -> Stack
Fold over all key-value pairs in a map with an accumulator.

Stack effect: ( Map init Quotation – result ) where Quotation : ( acc key value – acc’ )

The quotation receives the accumulator, key, and value, and must return the new accumulator. Iteration order is not guaranteed.

Safety

Stack must have Quotation on top, init below, and Map below that