patch_seq_report_init

Function patch_seq_report_init 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_report_init( counters: *const u64, names: *const *const u8, count: i64, )
Register instrumentation data from compiled binary (tier 2)

Safety

  • counters must point to a valid array of count i64 values
  • names must point to a valid array of count C string pointers
  • Both must remain valid for the program’s lifetime (they’re static globals)