patch_seq_string_equal

Function patch_seq_string_equal 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_string_equal(stack: Stack) -> Stack
Get the Unicode code point at a character index

Stack effect: ( str int – int )

Returns the code point value at the given character index. Returns -1 if index is out of bounds.

Safety

Stack must have a String and Int on top