patch_seq_chan_send

Function patch_seq_chan_send 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_chan_send(stack: Stack) -> Stack
Send a value through a channel.

Stack effect: ( value Channel – Bool )

Returns true on success, false if the channel is closed (either via chan.close or because every receiver has been dropped).

Safety

Stack must have a Channel on top and a value below it.