patch_seq_map_each

Function patch_seq_map_each 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn patch_seq_map_each(stack: Stack) -> Stack
Iterate over all key-value pairs in a map, calling a quotation for each.

Stack effect: ( Map Quotation – ) where Quotation : ( key value – )

The quotation receives each key and value on a fresh stack. Iteration order is not guaranteed.

Safety

Stack must have a Quotation/Closure on top and a Map below