#[unsafe(no_mangle)]pub unsafe extern "C" fn patch_seq_string_join(stack: Stack) -> StackExpand description
Join a list of strings with a separator.
Stack effect: ( Variant String – String )
Each element in the list is converted to its string representation and joined with the separator between them.
list-of "a" lv "b" lv "c" lv ", " string.join
# Result: "a, b, c"Safety
Stack must have a String (separator) on top and a Variant (list) below